<?php
/**
 * Arabic language file
 *
 * @author Yaman Hokan <always.smile.yh@hotmail.com>
 * @author Usama Akkad <uahello@gmail.com>
 * @author uahello@gmail.com
 */
$lang['menu']                  = 'إدارة الملحقات';
$lang['download']              = 'نزّل و ثبت اضافة جديدة';
$lang['manage']                = 'الإضافات المثبتة';
$lang['btn_info']              = 'معلومات';
$lang['btn_update']            = 'حدّث';
$lang['btn_delete']            = 'احذف';
$lang['btn_settings']          = 'إعدادات';
$lang['btn_download']          = 'نزل';
$lang['btn_enable']            = 'احفظ';
$lang['url']                   = 'رابط';
$lang['installed']             = 'ثُبتت:';
$lang['lastupdate']            = 'آخر تحديث:';
$lang['source']                = 'المصدر:';
$lang['unknown']               = 'مجهول';
$lang['updating']              = 'تُحدث ...';
$lang['updated']               = 'الاضافة %s حُدثت بنجاح';
$lang['updates']               = 'الاضافة التالية حُدثت بنجاح';
$lang['update_none']           = 'لا يوجد تحديثات.';
$lang['deleting']              = 'تُحذف ... ';
$lang['deleted']               = 'حُذفت الإضافة %s.';
$lang['downloading']           = 'يُنزل ...';
$lang['downloaded']            = 'الاضافة %s ثبتت بنجاح';
$lang['downloads']             = 'الاضافة التالية ثبتت بنجاح:';
$lang['download_none']         = 'لم يجد إضافة، أو ان هناك مشكلة غير معروفة أثناء التنزيل و التثبيت.';
$lang['plugin']                = 'الإضافة:';
$lang['components']            = 'المكون:';
$lang['noinfo']                = 'لم تعطي الإضافة أية معلومة، قد تكون معطوبة.';
$lang['name']                  = 'الاسم :';
$lang['date']                  = 'التاريخ :';
$lang['type']                  = 'النوع :';
$lang['desc']                  = 'الوصف :';
$lang['author']                = 'الكاتب :';
$lang['www']                   = 'الشابكة :';
$lang['error']                 = 'حث خطأ مجهول.';
$lang['error_download']        = 'تعذر تنزيل ملف الاضافة: %s';
$lang['error_badurl']          = 'اشتبه بعنوان خاطئ - تعذر الحصول على الاسم من العنوان';
$lang['error_dircreate']       = 'تعذر إنشاء مجلد مؤقت للتنزيل';
$lang['error_decompress']      = 'تعذر على مدير الاضافات فك ضغط الملف المُنزّل. قد يكون ذلك نتيجة لتنزيل خاطئ، في هذه الحالة أعد المحاولة; أو ان هيئة الضغط غير معروفة، في هذه الحالة عليك تنزيل و تثبيت الاضافة يدويا.';
$lang['error_copy']            = 'كان هناك خطأ في نسخ ملف عند محاولة تثبيت ملفات للإضافة <em>%s</em>: قد يكون القرص ممتلئا أو أن صلاحيات الوصول للملف خاطئة. لربما نتج عن ذلك اضافة مثبته جزئيا تجعل نظام الويكي غير ثابت.';
$lang['error_delete']          = 'كان هناك خطأ عند محاولة حذف الاضافة <em>%s</em>. السبب الاكثر احتمالا هو صلاحيات غير كافية على الملف أو المجلد';
$lang['enabled']               = 'الاضافة %s فُعلت.	';
$lang['notenabled']            = 'تعذر تفعيل الاضافة %s، تحقق من اذونات الملف.';
$lang['disabled']              = 'عُطلت الإضافة %s.';
$lang['notdisabled']           = 'تعذر تعطيل الإضافة %s، تحقق من اذونات الملف.';
$lang['packageinstalled']      = 'حزمة الإضافة (%d plugin(s): %s) ثبتت بنجاج.';
